@@ -1,5 +1,7 @@
+from time import time
 from jiange.log import LogAgent
 from jiange.file import dump_json
+from jiange.time import get_time_string
 
 
 class AgentBase(object):
@@ -26,16 +28,13 @@ class AgentBase(object):
         """
         raise NotImplementedError
 
-    def log_request_response(self, request, response):
+    def log_request_response(self, request, response, **kwargs):
         body = {
+            'timestamp': int(time() * 1000),
+            'date': get_time_string(),
             'request': request,
             'response': response,
-            'skill_name': self.skill_name
+            **kwargs
         }
         body = dump_json(body, indent=False)
         self.log.info(body)
-
-    def log_info(self, body):
-        if isinstance(body, dict):
-            body = dump_json(body, indent=False)
-        self.log.info(body)
