@@ -26,9 +26,10 @@ class LogAgent():
         log_file = os.path.join(path_tgt, 'log.txt')
         log_level = logging.INFO
         logger = logging.getLogger("loggingmodule.NomalLogger")
-        # 单个日志文件最多 25M
-        handler = logging.handlers.RotatingFileHandler(log_file, maxBytes=1024 * 1024 * 25, backupCount=10, encoding='utf8')
-        formatter = logging.Formatter("[%(levelname)s][%(filename)s][%(asctime)s]%(message)s")
+        # 单个日志文件最多 50M
+        handler = logging.handlers.RotatingFileHandler(log_file, maxBytes=1024 * 1024 * 50, backupCount=10, encoding='utf8')
+        # formatter = logging.Formatter("[%(levelname)s][%(filename)s][%(asctime)s]%(message)s")
+        formatter = logging.Formatter("")
         handler.setFormatter(formatter)
         logger.addHandler(handler)
         logger.setLevel(log_level)
